@@ -3,14 +3,14 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATION_SETTINGS_PRIVATE_H
-#define KDECORATION2_DECORATION_SETTINGS_PRIVATE_H
+#pragma once
 
 #include "../decorationdefines.h"
 #include <QFont>
 #include <QFontMetricsF>
-#include <QVector>
+#include <QList>
 #include <kdecoration2/private/kdecoration2_private_export.h>
+#include <memory>
 
 //
 //  W A R N I N G
@@ -34,8 +34,8 @@ public:
     virtual bool isOnAllDesktopsAvailable() const = 0;
     virtual bool isAlphaChannelSupported() const = 0;
     virtual bool isCloseOnDoubleClickOnMenu() const = 0;
-    virtual QVector<DecorationButtonType> decorationButtonsLeft() const = 0;
-    virtual QVector<DecorationButtonType> decorationButtonsRight() const = 0;
+    virtual QList<DecorationButtonType> decorationButtonsLeft() const = 0;
+    virtual QList<DecorationButtonType> decorationButtonsRight() const = 0;
     virtual BorderSize borderSize() const = 0;
     virtual QFont font() const;
     virtual QFontMetricsF fontMetrics() const;
@@ -55,8 +55,6 @@ protected:
 
 private:
     class Private;
-    const QScopedPointer<Private> d;
+    const std::unique_ptr<Private> d;
 };
 }
-
-#endif
